@@ -6,6 +6,7 @@ from isc_common.json import BytesToJson
 
 logger = logging.getLogger(__name__)
 
+
 class RequestData:
     def __init__(self, _dict=None, request=None):
         if request:
@@ -158,10 +159,28 @@ class DSRequest(RPCRequest):
             res = dict((key, value) for (key, value) in res.items() if not key.startswith('_') and key not in excluded_keys)
         return res
 
+    def get_all_data(self, excluded_keys=['grid']):
+        res = None
+        if isinstance(self.json, dict):
+            data = self.json.get('data')
+            if isinstance(data, dict):
+                res = data
+            elif isinstance(data, str):
+                return data
+            else:
+                res = self.json
+
+        return res
+
     def set_data(self, data):
         if isinstance(data, dict):
             setAttr(self.json, 'data', data)
 
+    def set_criteria(self, criteria, excluded_keys=['grid']):
+        data = self.get_all_data(excluded_keys=excluded_keys)
+        if isinstance(data, dict):
+            setAttr(data, 'criteria', criteria)
+
     def get_criteria(self, excluded_keys=['grid']):
         data = self.get_data(excluded_keys=excluded_keys)
         criteria = data.get('criteria')
