@@ -519,6 +519,16 @@ class CommonManager(Manager):
                 setAttr(res, key, value)
         return res
 
+    def delete_dbl_underscore_element(self, data):
+        if not isinstance(data, dict):
+            raise Exception('data must be dict')
+
+        res = dict()
+        for key, value in data.items():
+            if str(key).find('_', 0, 1) == -1 and str(key).find('__') == -1:
+                setAttr(res, key, value)
+        return res
+
     def refresh_mat_view(self, mat_view):
         with connection.cursor() as cursor:
             logger.debug(f'Refreshing: {mat_view}')
@@ -826,9 +836,12 @@ class CommonManager(Manager):
             for id, mode in tuple_ids:
                 if mode == 'hide':
                     super().filter(id=id).soft_delete()
+                    res += 1
+                elif mode == 'visible':
+                    super().filter(id=id).soft_restore()
                 else:
                     qty, _ = super().filter(id=id).delete()
-                res += qty
+                    res += qty
         return res
 
     def get_ex(self, *args, **kwargs):
