@@ -167,6 +167,9 @@ def compare_2_dict(dict1, dict2):
 
 
 class Set:
+    _lst = None
+    _set = None
+
     def __init__(self, lst):
         if isinstance(lst, set):
             self._set = set
